config.title = "Sphere fired into air."
print(config.title)

no_flow_times = 5.0
Db = 2
Rc = Db/2
setGasModel('air-5sp-2T.gas')
p_inf = 4850.0 -- Pa
T_inf = 293.0 -- K
u_inf = 3490.0 -- m/s
inflow = FlowState:new{p=p_inf, T=T_inf, T_modes={T_inf}, velx=u_inf,
                       massf={N2=0.767,O2=0.233}}

body_flow_time = Db/u_inf
config.reacting = true
config.reactions_file = 'air-5sp-6r-2T.chem'
config.energy_exchange_file = 'air-VT.exch'
config.dimensions = 2
config.axisymmetric = true -- make sure this is sphere, not cylinder
config.flux_calculator = "ausmdv"
config.interpolation_order = 2
config.interpolation_delay = 3*body_flow_time
config.grid_motion = "shock_fitting"
config.gasdynamic_update_scheme = "moving_grid_2_stage"
config.shock_fitting_delay = body_flow_time
config.max_invalid_cells = 20
config.adjust_invalid_cell_data = true
config.max_time = no_flow_times*body_flow_time
config.max_step = 80000
config.dt_init = 1.0e-11
config.cfl_value = 0
config.dt_plot = config.max_time/20
config.viscous = true

-- for test purposes (loads):
config.write_loads = true
config.boundary_groups_for_loads = "loads"
config.dt_loads = config.dt_plot



-- import mesh files from SU2
grid = UnstructuredGrid:new{filename="forsu_new2.su2", fmt="su2text"}

-- Set boundary conditions since this mesh system original from openfoam(inlet, object, oulet, front, back, bottom))
my_bcDict = {inlet=InFlowBC_Supersonic:new{flowState=inflow},
	     outlet=OutFlowBC_Simple:new{},
	     WALL=WallBC_NoSlip_FixedT:new{Twall=300, group="loads"},
	    }
blk = FluidBlock:new{grid=grid, initialState=inflow,
                     bcDict=my_bcDict}

print "All done."
